@@ -45,7 +45,7 @@ class LookupController(TGController):
 class DeprecatedLookupController(TGController):
 
     @expose()
-    def lookup(self, a, *args):
+    def _lookup(self, a, *args):
         return LookupHelper(a), args
 
 
@@ -253,18 +253,16 @@ class ExtraRestController(RestController):
     def post_delete(self, nr):
         return "rest post delete %s" % nr
 
-    class sub(TGController):
-
+    class SubClass(TGController):
         @expose()
         def index(self):
             return "rest sub index"
 
+    sub = SubClass()
     subrest = SubRestController()
     optsubrest = OptionalArgumentRestController()
     reqsubrest = RequiredArgumentRestController()
 
-    _custom_actions = ['archive']
-
     @expose()
     def post_archive(self):
         return 'got to post archive'
@@ -303,8 +301,6 @@ class BasicRestController(RestController):
     def other(self):
         return "rest other"
 
-    _custom_actions = ['archive']
-
     @expose()
     def archive(self):
         return 'got to archive'
