@@ -60,23 +60,20 @@ class CoreDispatcher(WSGIController):
             url as string
 
         """
-        if not pylons.config.get('disable_request_extensions', False):
-            pylons.request.response_type = None
-            pylons.request.response_ext = None
-            if url_path and '.' in url_path[-1]:
-                last_remainder = url_path[-1]
-                mime_type, encoding = mimetypes.guess_type(last_remainder)
-                if mime_type:
-                    extension_spot = last_remainder.rfind('.')
-                    extension = last_remainder[extension_spot:]
-                    url_path[-1] = last_remainder[:extension_spot]
-                    pylons.request.response_type = mime_type
-                    pylons.request.response_ext = extension
-
         params = pylons.request.params.mixed()
 
         state = DispatchState(pylons.request,
             self, params, url_path, pylons.config.get('ignore_parameters', []))
+
+        pylons.request.response_type = None
+        if not pylons.config.get('disable_request_extensions', False):
+            ext = state.extension
+            if ext is not None:
+                ext = '.' + ext
+                mime_type, encoding = mimetypes.guess_type(ext)
+                pylons.request.response_type = mime_type
+            pylons.request.response_ext = ext
+
         state = state.controller._dispatch(state, url_path)
 
         pylons.tmpl_context.controller_url = '/'.join(
